import { Stack } from 'aws-cdk-lib';
import { IConstruct } from 'constructs';
/**
 * A utility class that have common functions.
 */
export declare class Utils {
    /**
     * Will append the suffix to the given name if the name do not contain the suffix
     * @param name - a string
     * @param suffixes - the string to append
     * @returns the name with the suffix appended if necessary delimited by a hyphen
     */
    static appendIfNecessary(name: string, ...suffixes: string[]): string;
    /**
     * Will wrap the given string using the given delimiter.
     * @param str - the string to wrap
     * @param delimiter - the delimiter to use
     * @returns the wrapped string
     */
    static wrap(str: string, delimiter: string): string;
    /**
     * Will check if the given string starts with the given prefix.
     * @param str - a string
     * @param s - the prefix to check
     */
    static startsWith(str: string, s: string): boolean;
    /**
     * Will check if the given string ends with the given suffix.
     * @param str - a string
     * @param s - suffix to check
     */
    static endsWith(str: string, s: string): boolean;
    /**
     * Will check if the given object is empty
     * @param value
     */
    static isEmpty(value?: any): boolean;
    /**
     * Will convert the given string to lower case and transform any spaces to hyphens
     * @param str - a string
     */
    static kebabCase(str: string): string;
    /**
     * Will convert the given string to camel case.
     * @param str - a string
     */
    static camelCase(str: string): string;
    /**
     * Will escape double quotes in the given string.
     */
    static escapeDoubleQuotes(str: string): string;
    /**
     * Splits a given Github URL and extracts the owner and repo name
     * @param url
     */
    static parseGithubUrl(url: string): any;
    /**
     * A utility function that will print the content of a CDK stack.
     * @warning This function is only used for debugging purpose.
     * @param stack - a valid stack
     */
    static prettyPrintStack(stack: Stack, persist?: boolean, path?: string): void;
    /**
     * A utility function that will obtain the first state machine definition from the given stack.
     * @param stack - a stack that contains at least one state machine resource.
     */
    static fetchStepFuncitonStateDefinition(stack: Stack): any;
    /**
     * Will disable the CDK NAG rule for the given construct and its children.
     * @param scope - the scope to disable the rule for
     * @param ruleId - the rule id to disable
     * @param reason - reason for disabling the rule.
     */
    static suppressNagRule(scope: IConstruct, ruleId: string, reason?: string): void;
    /**
     * Will check if the given string is contained in another string.
     * @param str - a string
     * @param s - the string to check for
     */
    static contains(str: string, s: string): boolean;
    /**
     * Merges two objects
     */
    static merge(obj1: any, obj2: any): any;
    /**
     * joins a string array using the given seperator
     * @param arr
     * @param separator
     */
    static join(arr: string[] | undefined, separator?: string): string;
}
export declare class FileUtils {
    /**
     * Will read the file from the given path and return the content as a string.
     * @param path
     */
    static readFile(path: string): string;
}
